View source: R/clusterprocess.R
| clusterprocess | R Documentation |
Creates an object representing a cluster point process model with the specified parameters. Typically used for simulations or calculations about such a model.
clusterprocess(name = "Thomas", ..., mu, kappa, scale)
name |
Name of the cluster process. One of
|
... |
Other arguments needed for the model. |
mu |
Mean cluster size. A single number, or a pixel image. |
kappa |
Parent intensity. A single number. |
scale |
Cluster scale parameter of the model. |
This function creates an object representing a Neyman-Scott-Cox
cluster process model with the specified parameter values.
The object belongs to the class "clusterprocess".
This is different from the model-fitting function
kppm which fits such a model to a point pattern dataset.
There are methods for simulating a "clusterprocess",
calculating its moments, and other purposes, listed under
See Also.
Object of class "clusterprocess".
Methods for
simulate,
predict,
intensity,
print,
clusterradius and
reach
are supplied in package spatstat.random
and documented under methods.clusterprocess.
The functions
Kmodel,
pcfmodel,
psib,
persist,
clusterstrength and
varcount
in package spatstat.model
can also be applied to a "clusterprocess".
m <- clusterprocess("Thomas", kappa=10, mu=5, scale=0.1)
simulate(m, win=square(2))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.