methods.clusterprocess: Methods for Cluster Models

methods.clusterprocessR Documentation

Methods for Cluster Models

Description

Methods for the class "clusterprocess" of cluster point process models with specified values of the parameters.

Usage

 ## S3 method for class 'clusterprocess'
intensity(X, ...)

 ## S3 method for class 'clusterprocess'
predict(object, ...,
                  locations, type = "intensity", ngrid = NULL)

 ## S3 method for class 'clusterprocess'
print(x, ...)

 ## S3 method for class 'clusterprocess'
clusterradius(model,...,thresh=NULL, precision=FALSE)

 ## S3 method for class 'clusterprocess'
reach(x, ..., epsilon)

 ## S3 method for class 'clusterprocess'
simulate(object, nsim=1, ..., win=unit.square(), window=win)

Arguments

model, object, x, X

Object of class "clusterprocess".

...

Arguments passed to other methods.

locations

Locations where prediction should be performed. A window or a point pattern.

type

Currently must equal "intensity".

ngrid

Pixel grid dimensions for prediction, if locations is a rectangle or polygon.

thresh, epsilon

Tolerance thresholds

precision

Logical value stipulating whether the precision should also be returned.

win, window

Window (object of class "owin") in which the simulated pattern should be generated.

nsim

Number of simulated patterns to be generated.

Details

An object of class "clusterprocess" represents a Neyman-Scott-Cox cluster process model with specified parameter values.

This page documents methods for printing, simulating and predicting such models, supplied by the package spatstat.random. Other methods are supplied in other packages.

Value

Same as for other methods.

Author(s)

\adrian

See Also

clusterprocess

Examples

  m <- clusterprocess("Thomas", kappa=10, mu=5, scale=0.1)
  m2 <- clusterprocess("VarGamma", kappa=10, mu=10, scale=0.1, nu=0.7)
  m
  m2
  intensity(m)
  reach(m)
  clusterradius(m)
  Z <- predict(m, locations=square(2))
  X <- simulate(m, win=square(2))

spatstat.random documentation built on May 24, 2026, 9:07 a.m.