runifpoint3: Generate N Uniform Random Points in Three Dimensions

View source: R/randompp3.R

runifpoint3R Documentation

Generate N Uniform Random Points in Three Dimensions

Description

Generate a random point pattern containing n independent, uniform random points in three dimensions.

Usage

runifpoint3(n, domain = box3(), ..., nsim=1, drop=TRUE, ex=NULL)

Arguments

n

Number of points to be generated.

domain

Three-dimensional box in which the process should be generated. An object of class "box3".

...

Ignored.

nsim

Number of simulated realisations to be generated.

drop

Logical. If nsim=1 and drop=TRUE (the default), the result will be a point pattern, rather than a list containing a point pattern.

ex

An example point pattern (object of class "pp3") which will be used to determine the number of points n and the containing box domain.

Details

This function generates n independent random points, uniformly distributed in the three-dimensional box domain.

Value

If nsim = 1 and drop=TRUE, a point pattern in three dimensions (an object of class "pp3"). If nsim > 1, a list of such point patterns.

Author(s)

\adrian

and \rolf.

See Also

rpoispp3, rpoint3, pp3, box3

Examples

   X <- runifpoint3(50)

   runifpoint3(ex=osteo$pts[[1]])

spatstat.random documentation built on May 24, 2026, 9:07 a.m.