Learn R Programming

spatstat.random (version 3.4-5)

clusterprocess: Cluster Point Process Model

Description

Creates an object representing a cluster point process model with the specified parameters. Typically used for simulations or calculations about such a model.

Usage

clusterprocess(name = "Thomas", ..., mu, kappa, scale)

Value

Object of class "clusterprocess".

Arguments

name

Name of the cluster process. One of "Thomas", "MatClust", "VarGamma" or "Cauchy".

...

Other arguments needed for the model.

mu

Mean cluster size. A single number, or a pixel image.

kappa

Parent intensity. A single number.

scale

Cluster scale parameter of the model.

Author

Adrian Baddeley Adrian.Baddeley@curtin.edu.au

Details

This function creates an object representing a Neyman-Scott-Cox cluster process model with the specified parameter values. The object belongs to the class "clusterprocess".

This is different from the model-fitting function kppm which fits such a model to a point pattern dataset.

There are methods for simulating a "clusterprocess", calculating its moments, and other purposes, listed under See Also.

See Also

Methods for simulate, predict, intensity, print, clusterradius and reach are supplied in package spatstat.random and documented under methods.clusterprocess.

The functions Kmodel, pcfmodel, psib, persist, clusterstrength and varcount in package spatstat.model can also be applied to a "clusterprocess".

Examples

Run this code
  m <- clusterprocess("Thomas", kappa=10, mu=5, scale=0.1)
  simulate(m, win=square(2))

Run the code above in your browser using DataLab