| rpoispp3 | R Documentation |
Generate a random three-dimensional point pattern using the homogeneous Poisson process.
rpoispp3(lambda, domain = box3(), ..., nsim=1, drop=TRUE, ex=NULL, lmax=NULL)
lambda |
Intensity of the Poisson process.
A single positive number, or a |
domain |
Three-dimensional box in which the process should be generated.
An object of class |
... |
Ignored. |
nsim |
Number of simulated realisations to be generated. |
drop |
Logical. If |
ex |
An example point pattern (object of class |
lmax |
Maximum possible value of the intensity function |
This function generates a realisation
of the Poisson process in three dimensions,
with intensity lambda (points per unit volume).
If lambda is a single number, the homogeneous Poisson process
with constant intensity lambda is generated.
If lambda is a function with arguments x,y,z, the
inhomogeneous Poisson process with intensity function
lambda(x,y,z) is generated. In this case the argument
lmax is required.
The realisation is generated inside the three-dimensional region
domain which currently must be a rectangular box (object of
class "box3").
If nsim = 1 and drop=TRUE, a point pattern in
three dimensions (an object of class "pp3").
If nsim > 1, a list of such point patterns.
The intensity lambda is the expected number of points
per unit volume.
and \rolf.
runifpoint3,
pp3,
box3
X <- rpoispp3(50)
rpoispp3(ex=osteo$pts[[1]])
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.