powered by
Generate a random point pattern containing n independent, uniform random points in three dimensions.
n
runifpoint3(n, domain = box3(), ..., nsim=1, drop=TRUE, ex=NULL)
If nsim = 1 and drop=TRUE, a point pattern in three dimensions (an object of class "pp3"). If nsim > 1, a list of such point patterns.
nsim = 1
drop=TRUE
"pp3"
nsim > 1
Number of points to be generated.
Three-dimensional box in which the process should be generated. An object of class "box3".
"box3"
Ignored.
Number of simulated realisations to be generated.
Logical. If nsim=1 and drop=TRUE (the default), the result will be a point pattern, rather than a list containing a point pattern.
nsim=1
An example point pattern (object of class "pp3") which will be used to determine the number of points n and the containing box domain.
domain
Adrian Baddeley Adrian.Baddeley@curtin.edu.au and Rolf Turner rolfturner@posteo.net.
This function generates n independent random points, uniformly distributed in the three-dimensional box domain.
rpoispp3, rpoint3, pp3, box3
rpoispp3
rpoint3
pp3
box3
X <- runifpoint3(50) runifpoint3(ex=osteo$pts[[1]])
Run the code above in your browser using DataLab